CIMSocket class

Constructors

CIMSocket({required ValueChanged<Model> onMessageReceived, required ValueChanged<bool> onConnectionStatusChanged})

Properties

deviceInfoPlugin → DeviceInfoPlugin
final
endCode String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
onConnectionStatusChanged ValueChanged<bool>
final
onMessageReceived ValueChanged<Model>
final
port int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
socket Socket?
getter/setter pair
timer ↔ TimerUtil
getter/setter pair
uid String?
getter/setter pair
uri String?
getter/setter pair

Methods

connect() Future
disConnect() Future
init(String uri, int port, String uid) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendLoginMsg() Future
sendPong() Future
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited